Enum objc_encode::encoding::Primitive
[−]
[src]
pub enum Primitive {
Char,
Short,
Int,
Long,
LongLong,
UChar,
UShort,
UInt,
ULong,
ULongLong,
Float,
Double,
Bool,
Void,
String,
Object,
Block,
Class,
Sel,
Unknown,
BitField(u32),
}An encoding for a "primitive" type which is not a composition of other types.
Variants
CharShortIntLongLongLongUCharUShortUIntULongULongLongFloatDoubleBoolVoidStringObjectBlockClassSelUnknownBitField(u32)Trait Implementations
impl Clone for Primitive[src]
fn clone(&self) -> Primitive
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Copy for Primitive[src]
impl Debug for Primitive[src]
impl Encoding for Primitive[src]
type PointerTarget = Never
The type of Encoding that Self will use if it is an encoding for a pointer to describe its target. Read more
type ArrayItem = Never
The type of Encoding that Self will use if it is an encoding for an array to describe its items. Read more
type StructFields = Never
The type of Encodings that Self will use if it is an encoding for a struct to describe its fields. Read more
type UnionMembers = Never
The type of Encodings that Self will use if it is an encoding for a union to describe its members. Read more
fn descriptor(&self) -> Descriptor<Never, Never, Never, Never>
Returns a Descriptor that describes what kind of encoding self is.
fn eq_encoding<T: ?Sized + Encoding>(&self, other: &T) -> bool
Returns whether self is equal to the given Encoding.
fn write<W: Write>(&self, writer: &mut W) -> Result
Writes the string representation of self to the given writer.
impl Display for Primitive[src]
fn fmt(&self, formatter: &mut Formatter) -> Result
Formats the value using the given formatter. Read more
impl<E: ?Sized> PartialEq<E> for Primitive where
E: Encoding, [src]
E: Encoding,
fn eq(&self, other: &E) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.